/******************************************************************************
*******************************************************************************

  FILE NAME:	tcl_ext.h		MODULE: tcl
  AUTHOR: 	Andy Seigel

  ABSTRACT:	Some Synopsys extensions to Tcl.  Almost nobody should
		be including this file.  cci uses it.

  SYNOPSYS CONFIDENTIAL
  Copyright (C)1998 Synopsys Inc. All Rights Reserved. Forwarding or copying
  of this document, in any medium, in whole or in part, or disclosure of its
  contents, to other than the authorized recipient, is strictly prohibited.

*******************************************************************************
******************************************************************************/
#ifndef TCL_EXT_H
#define TCL_EXT_H

#include <tcl.h>

/*
 * These macros are used to control whether functions are being declared for
 * import or export.  If a function is being declared while it is being built
 * to be included in a shared library, then it should have the DLLEXPORT
 * storage class.  If is being declared for use by a module that is going to
 * link against the shared library, then it should have the DLLIMPORT storage
 * class.  If the symbol is beind declared for a static build or for use from a
 * stub library, then the storage class should be empty.
 *
 * The convention is that a macro called BUILD_xxxx, where xxxx is the
 * name of a library we are building, is set on the compile line for sources
 * that are to be placed in the library.  When this macro is set, the
 * storage class will be set to DLLEXPORT.  At the end of the header file, the
 * storage class will be reset to DLLIMPORT.
 */
#undef TCL_STORAGE_CLASS
#ifdef BUILD_tcl
#   define TCL_STORAGE_CLASS DLLEXPORT
#else
#   ifdef USE_TCL_STUBS
#      define TCL_STORAGE_CLASS
#   else
#      define TCL_STORAGE_CLASS DLLIMPORT
#   endif
#endif


/**
 * typedef for the pre-create-proc daemon.  If this is registered, it
 * will be called just before a proc is created.  If it returns 0, the
 * proc creation will be aborted and TCL_ERROR will result.
 **/
typedef int (*Tcl_PreCreateProcDmn) _ANSI_ARGS_((Tcl_Interp *interp,
						 char *proc_name,
						 char **emsg));

/**
 * typedef for the post-create-proc daemon.  If this is registered, it
 * will be called just after a proc is created.
 **/
typedef void (*Tcl_PostCreateProcDmn) _ANSI_ARGS_((Tcl_Interp *interp,
						   char *proc_name));


/**
 * typedef for the pre-execute-proc daemon.  If this is registered, it
 * will be called just before a proc is executed.  If it returns 0, the
 * proc execution will be aborted and TCL_ERROR will result.
 **/
typedef int (*Tcl_PreExecProcDmn) _ANSI_ARGS_((Tcl_Interp *interp,
					       int *argcP, char **argv,
					       int proc_level));

/**
 * typedef for the post-execute-proc daemon.  If this is registered, it
 * will be called just after a proc has executed.
 **/
typedef void (*Tcl_PostExecProcDmn) _ANSI_ARGS_((Tcl_Interp *interp,
						 int proc_level,
						 int status));


/** tclProc.c Public Prototypes **/
EXTERN void Tcl_RegisterPreCreateProcDaemon _ANSI_ARGS_((Tcl_PreCreateProcDmn func));
EXTERN void Tcl_RegisterPostCreateProcDaemon _ANSI_ARGS_((Tcl_PostCreateProcDmn func));
EXTERN void Tcl_RegisterPreExecProcDaemon _ANSI_ARGS_((Tcl_PreExecProcDmn func));
EXTERN void Tcl_RegisterPostExecProcDaemon _ANSI_ARGS_((Tcl_PostExecProcDmn func));
/** end Public Prototypes for tclProc.c **/

#undef TCL_STORAGE_CLASS
#define TCL_STORAGE_CLASS

#endif
